1. Introduction — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »

# 1. Introduction

Umbra is the main package of sIBL_GUI and sIBL_Reporter.

#### Previous topic

Welcome to Umbra 1‘s documentation!

#### Next topic

2. Installation

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »

© Copyright 2012, Thomas Mansencal. Created using Sphinx 1.1.3.